*************************************
Sources Detection (``mpdaf.sdetect``)
*************************************

The ``mpdaf.sdetect`` package contains different methods to detect sources.

Contents:

.. toctree::
   :maxdepth: 2

   source
   catalog
   muselet


Reference/API
=============

.. automodapi:: mpdaf.sdetect
   :no-main-docstr:
   :no-inherited-members:
